API Reference
==============

Here is the reference documentation for the eprllib API. This library provides a set of tools and utilities 
for the simulation and evaluation of multi-agent environments in EnergyPlus.

.. automodule:: eprllib

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   Environment
   Agents
   Connectors
   Episodes
